@@ -645,7 +645,7 @@ func (ddb *DoltDB) CommitWithParentCommits(ctx context.Context, valHash hash.Has
 
 	commitSt, ok := ds.MaybeHead()
 	if !ok {
-		return nil, errors.New("commit has no head but commit succeeded (How?!?!?)")
+		return nil, errors.New("Commit has no head but commit succeeded. This is a bug.")
 	}
 
 	return NewCommit(ddb.db, commitSt), nil
@@ -1047,38 +1047,45 @@ func (ddb *DoltDB) CommitWithWorkingSet(
 	commit *PendingCommit, workingSet *WorkingSet,
 	prevHash hash.Hash,
 	meta *WorkingSetMeta,
-) error {
+) (*Commit, error) {
 	wsDs, err := ddb.db.GetDataset(ctx, workingSetRef.String())
 	if err != nil {
-		return err
+		return nil, err
 	}
 
 	headDs, err := ddb.db.GetDataset(ctx, headRef.String())
 	if err != nil {
-		return err
+		return nil, err
 	}
 
-	// logrus.Tracef("Updating working set with root %s", workingSet.RootValue().DebugString(ctx, true))
-
 	workingRootRef, stagedRef, mergeStateRef, err := workingSet.writeValues(ctx, ddb)
 	if err != nil {
-		return err
+		return nil, err
 	}
 
 	var metaSt types.Struct
 	metaSt, err = meta.toNomsStruct(ddb.db.Format())
 	if err != nil {
-		return err
+		return nil, err
 	}
 
-	_, _, err = ddb.db.CommitWithWorkingSet(ctx, headDs, wsDs, commit.Roots.Staged.valueSt, datas.WorkingSetSpec{
+	commitDataset, _, err := ddb.db.CommitWithWorkingSet(ctx, headDs, wsDs, commit.Roots.Staged.valueSt, datas.WorkingSetSpec{
 		Meta:        datas.WorkingSetMeta{Meta: metaSt},
 		WorkingRoot: workingRootRef,
 		StagedRoot:  stagedRef,
 		MergeState:  mergeStateRef,
 	}, prevHash, commit.CommitOptions)
 
-	return err
+	if err != nil {
+		return nil, err
+	}
+
+	commitSt, ok := commitDataset.MaybeHead()
+	if !ok {
+		return nil, errors.New("Commit has no head but commit succeeded. This is a bug.")
+	}
+
+	return NewCommit(ddb.db, commitSt), nil
 }
 
 // DeleteWorkingSet deletes the working set given
@@ -1129,6 +1136,12 @@ func (ddb *DoltDB) DeleteWorkspace(ctx context.Context, workRef ref.DoltRef) err
 	return err
 }
 
+// Rebase rebases the underlying db from disk, re-loading the manifest. Useful when another process might have made
+// changes to the database we need to read.
+func (ddb *DoltDB) Rebase(ctx context.Context) error {
+	return ddb.db.Rebase(ctx)
+}
+
 // GC performs garbage collection on this ddb. Values passed in |uncommitedVals| will be temporarily saved during gc.
 func (ddb *DoltDB) GC(ctx context.Context, uncommitedVals ...hash.Hash) error {
 	collector, ok := ddb.db.(datas.GarbageCollector)
