@@ -36,18 +36,24 @@ import (
 	"github.com/dolthub/dolt/go/libraries/doltcore/grpcendpoint"
 	"github.com/dolthub/dolt/go/libraries/doltcore/ref"
 	"github.com/dolthub/dolt/go/libraries/doltcore/table/editor"
+	"github.com/dolthub/dolt/go/libraries/utils/config"
 	"github.com/dolthub/dolt/go/libraries/utils/filesys"
 	"github.com/dolthub/dolt/go/store/hash"
 	"github.com/dolthub/dolt/go/store/types"
 )
 
 const (
-	DefaultLoginUrl       = "https://dolthub.com/settings/credentials"
-	DefaultMetricsHost    = "eventsapi.dolthub.com"
-	DefaultMetricsPort    = "443"
+	defaultInitBranch = "master"
+
+	DefaultLoginUrl = "https://dolthub.com/settings/credentials"
+
+	DefaultMetricsHost = "eventsapi.dolthub.com"
+	DefaultMetricsPort = "443"
+
 	DefaultRemotesApiHost = "doltremoteapi.dolthub.com"
 	DefaultRemotesApiPort = "443"
-	tempTablesDir         = "temptf"
+
+	tempTablesDir = "temptf"
 )
 
 var zeroHashStr = (hash.Hash{}).String()
@@ -155,6 +161,11 @@ func Load(ctx context.Context, hdp HomeDirProvider, fs filesys.Filesys, urlStr,
 	return dEnv
 }
 
+func GetDefaultInitBranch(cfg config.ReadableConfig) string {
+	s := GetStringOrDefault(cfg, InitBranchName, defaultInitBranch)
+	return *s
+}
+
 // initWorkingSetFromRepoState sets the working set for the env's head to mirror the contents of the repo state file.
 // This is only necessary to migrate repos written before this method was introduced, and can be removed after 1.0
 func (dEnv *DoltEnv) initWorkingSetFromRepoState(ctx context.Context) error {
@@ -397,12 +408,11 @@ func (dEnv *DoltEnv) InitDBAndRepoState(ctx context.Context, nbf *types.NomsBinF
 func (dEnv *DoltEnv) InitDBWithTime(ctx context.Context, nbf *types.NomsBinFormat, name, email string, t time.Time) error {
 	var err error
 	dEnv.DoltDB, err = doltdb.LoadDoltDB(ctx, nbf, dEnv.urlStr, dEnv.FS)
-
 	if err != nil {
 		return err
 	}
 
-	err = dEnv.DoltDB.WriteEmptyRepoWithCommitTime(ctx, name, email, t)
+	err = dEnv.DoltDB.WriteEmptyRepoWithCommitTime(ctx, GetDefaultInitBranch(dEnv.Config), name, email, t)
 	if err != nil {
 		return doltdb.ErrNomsIO
 	}
@@ -412,8 +422,8 @@ func (dEnv *DoltEnv) InitDBWithTime(ctx context.Context, nbf *types.NomsBinForma
 
 // InitializeRepoState writes a default repo state to disk, consisting of a master branch and current root hash value.
 func (dEnv *DoltEnv) InitializeRepoState(ctx context.Context) error {
-	cs, _ := doltdb.NewCommitSpec(doltdb.MasterBranch)
-	commit, err := dEnv.DoltDB.Resolve(ctx, cs, nil)
+	branchName := GetDefaultInitBranch(dEnv.Config)
+	commit, err := dEnv.DoltDB.ResolveCommitRef(ctx, ref.NewBranchRef(branchName))
 	if err != nil {
 		return err
 	}
@@ -423,7 +433,7 @@ func (dEnv *DoltEnv) InitializeRepoState(ctx context.Context) error {
 		return err
 	}
 
-	dEnv.RepoState, err = CreateRepoState(dEnv.FS, doltdb.MasterBranch)
+	dEnv.RepoState, err = CreateRepoState(dEnv.FS, branchName)
 	if err != nil {
 		return ErrStateUpdate
 	}
@@ -494,12 +504,16 @@ func (dEnv *DoltEnv) WorkingRoot(ctx context.Context) (*doltdb.RootValue, error)
 }
 
 func (dEnv *DoltEnv) WorkingSet(ctx context.Context) (*doltdb.WorkingSet, error) {
-	workingSetRef, err := ref.WorkingSetRefForHead(dEnv.RepoState.CWBHeadRef())
+	return WorkingSet(ctx, dEnv.DoltDB, dEnv.RepoStateReader())
+}
+
+func WorkingSet(ctx context.Context, ddb *doltdb.DoltDB, rsr RepoStateReader) (*doltdb.WorkingSet, error) {
+	workingSetRef, err := ref.WorkingSetRefForHead(rsr.CWBHeadRef())
 	if err != nil {
 		return nil, err
 	}
 
-	workingSet, err := dEnv.DoltDB.ResolveWorkingSet(ctx, workingSetRef)
+	workingSet, err := ddb.ResolveWorkingSet(ctx, workingSetRef)
 	if err != nil {
 		return nil, err
 	}
