@@ -140,3 +140,38 @@ func GetSharedCols(schema Schema, cmpNames []string, cmpKinds []types.NomsKind)
 	}
 	return reuseTags
 }
+
+// ArePrimaryKeySetsDiffable checks if two schemas are diffable. Assumes the passed in schema are from the same table
+// between commits.
+func ArePrimaryKeySetsDiffable(fromSch, toSch Schema) bool {
+	if fromSch == nil && toSch == nil {
+		return false
+	} else if fromSch == nil {
+		return true
+	} else if fromSch.GetAllCols().Size() == 0 {
+		// Empty case
+		return true
+	}
+
+	// Keyless case for comparing
+	if IsKeyless(fromSch) && IsKeyless(toSch) {
+		return true
+	}
+
+	cc1 := fromSch.GetPKCols()
+	cc2 := toSch.GetPKCols()
+
+	if cc1.Size() != cc2.Size() {
+		return false
+	}
+
+	for i := 0; i < cc1.Size(); i++ {
+		c1 := cc1.GetAtIndex(i)
+		c2 := cc2.GetAtIndex(i)
+		if (c1.Tag != c2.Tag) || (c1.IsPartOfPK != c2.IsPartOfPK) {
+			return false
+		}
+	}
+
+	return true
+}
