@@ -89,6 +89,19 @@ func (r ReadOnlyDatabase) IsReadOnly() bool {
 
 func (db Database) StartTransaction(ctx *sql.Context) (sql.Transaction, error) {
 	dsession := dsess.DSessFromSess(ctx.Session)
+
+	if !dsession.HasDB(ctx, db.Name()) {
+		init, err := GetInitialDBState(ctx, db)
+		if err != nil {
+			return nil, err
+		}
+
+		err = dsession.AddDB(ctx, init)
+		if err != nil {
+			return nil, err
+		}
+	}
+
 	return dsession.StartTransaction(ctx, db.Name())
 }
 
@@ -140,6 +153,41 @@ func NewDatabase(name string, dbData env.DbData, editOpts editor.Options) Databa
 	}
 }
 
+// GetInitialDBState returns the InitialDbState for |db|.
+func GetInitialDBState(ctx context.Context, db Database) (dsess.InitialDbState, error) {
+	rsr := db.DbData().Rsr
+	ddb := db.DbData().Ddb
+
+	headCommit, err := ddb.Resolve(ctx, rsr.CWBHeadSpec(), rsr.CWBHeadRef())
+	if err != nil {
+		return dsess.InitialDbState{}, err
+	}
+
+	ws, err := env.WorkingSet(ctx, ddb, rsr)
+	if err != nil {
+		return dsess.InitialDbState{}, err
+	}
+
+	remotes, err := rsr.GetRemotes()
+	if err != nil {
+		return dsess.InitialDbState{}, err
+	}
+
+	branches, err := rsr.GetBranches()
+	if err != nil {
+		return dsess.InitialDbState{}, err
+	}
+
+	return dsess.InitialDbState{
+		Db:         db,
+		HeadCommit: headCommit,
+		WorkingSet: ws,
+		DbData:     db.DbData(),
+		Remotes:    remotes,
+		Branches:   branches,
+	}, nil
+}
+
 // Name returns the name of this database, set at creation time.
 func (db Database) Name() string {
 	return db.name
