@@ -25,6 +25,8 @@ import (
 	"github.com/dolthub/dolt/go/libraries/doltcore/env"
 	"github.com/dolthub/dolt/go/libraries/doltcore/ref"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/dsess"
+	"github.com/dolthub/dolt/go/libraries/doltcore/table/editor"
+	"github.com/dolthub/dolt/go/libraries/utils/config"
 )
 
 const (
@@ -34,19 +36,25 @@ const (
 type DoltDatabaseProvider struct {
 	databases map[string]sql.Database
 	mu        *sync.RWMutex
+
+	cfg config.ReadableConfig
 }
 
 var _ sql.DatabaseProvider = DoltDatabaseProvider{}
 var _ sql.MutableDatabaseProvider = DoltDatabaseProvider{}
 var _ dsess.RevisionDatabaseProvider = DoltDatabaseProvider{}
 
-func NewDoltDatabaseProvider(databases ...Database) DoltDatabaseProvider {
+func NewDoltDatabaseProvider(config config.ReadableConfig, databases ...sql.Database) DoltDatabaseProvider {
 	dbs := make(map[string]sql.Database, len(databases))
 	for _, db := range databases {
 		dbs[strings.ToLower(db.Name())] = db
 	}
 
-	return DoltDatabaseProvider{databases: dbs, mu: &sync.RWMutex{}}
+	return DoltDatabaseProvider{
+		databases: dbs,
+		mu:        &sync.RWMutex{},
+		cfg:       config,
+	}
 }
 
 func (p DoltDatabaseProvider) Database(name string) (db sql.Database, err error) {
@@ -95,18 +103,32 @@ func (p DoltDatabaseProvider) AllDatabases() (all []sql.Database) {
 	return
 }
 
-func (p DoltDatabaseProvider) AddDatabase(db sql.Database) {
+func (p DoltDatabaseProvider) CreateDatabase(ctx *sql.Context, name string) error {
 	p.mu.Lock()
 	defer p.mu.Unlock()
 
+	mem, err := env.NewMemoryDbData(ctx, p.cfg)
+	if err != nil {
+		return err
+	}
+	opts := editor.Options{
+		Deaf: editor.NewDbEaFactory(
+			mem.Rsw.TempTableFilesDir(),
+			mem.Ddb.ValueReadWriter()),
+	}
+
+	db := NewDatabase(name, mem, opts)
 	p.databases[strings.ToLower(db.Name())] = db
+
+	return nil
 }
 
-func (p DoltDatabaseProvider) DropDatabase(name string) {
+func (p DoltDatabaseProvider) DropDatabase(ctx *sql.Context, name string) error {
 	p.mu.Lock()
 	defer p.mu.Unlock()
 
 	delete(p.databases, strings.ToLower(name))
+	return nil
 }
 
 func (p DoltDatabaseProvider) databaseForRevision(ctx context.Context, revDB string) (sql.Database, dsess.InitialDbState, bool, error) {
