@@ -33,6 +33,9 @@ var DoltFunctions = []sql.Function{
 	sql.FunctionN{Name: ConstraintsVerifyFuncName, Fn: NewConstraintsVerifyFunc},
 	sql.FunctionN{Name: ConstraintsVerifyAllFuncName, Fn: NewConstraintsVerifyAllFunc},
 	sql.FunctionN{Name: RevertFuncName, Fn: NewRevertFunc},
+	sql.FunctionN{Name: DoltPullFuncName, Fn: NewPullFunc},
+	sql.FunctionN{Name: DoltFetchFuncName, Fn: NewFetchFunc},
+	sql.FunctionN{Name: DoltPushFuncName, Fn: NewPushFunc},
 }
 
 // These are the DoltFunctions that get exposed to Dolthub Api.
